@@ -83,6 +83,7 @@ class Executor:  # pylint:disable=too-many-instance-attributes
         self.iut = iut
         self.etos = etos
         self.context = self.etos.config.get("context")
+        self.plugins = self.etos.config.get("plugins")
         self.result = True
 
     def load_regex(self):
@@ -130,7 +131,7 @@ class Executor:  # pylint:disable=too-many-instance-attributes
             for command in test_checkout:
                 checkout_file.write(f"{command} || exit 1\n")
 
-        self.logger.info("Checkout script:\n" "%s", checkout.read_text())
+        self.logger.info("Checkout script:\n %s", checkout.read_text())
 
         signal.signal(signal.SIGALRM, _test_checkout_signal_handler)
         signal.alarm(60)
@@ -150,7 +151,7 @@ class Executor:  # pylint:disable=too-many-instance-attributes
         executor = Path().joinpath("executor.sh")
         copy(base_executor, executor)
 
-        self.logger.info("Executor script:\n" "%s", executor.read_text(encoding="utf-8"))
+        self.logger.info("Executor script:\n %s", executor.read_text(encoding="utf-8"))
 
         test_command = ""
         parameters = []
@@ -167,12 +168,12 @@ class Executor:  # pylint:disable=too-many-instance-attributes
 
     def __enter__(self):
         """Enter context and set current test."""
-        self.etos.config.set("current_test", self.test_name)
+        self.etos.config.set("test_name", self.test_name)
         return self
 
     def __exit__(self, _type, value, traceback):
         """Exit context and unset current test."""
-        self.etos.config.set("current_test", None)
+        self.etos.config.set("test_name", None)
 
     def _pre_execution(self, command):
         """Write pre execution command to a shell script.
@@ -185,7 +186,7 @@ class Executor:  # pylint:disable=too-many-instance-attributes
             for arg in command:
                 environ_file.write(f"{arg} || exit 1\n")
         self.logger.info(
-            "Pre-execution script (includes ENVIRONMENT):\n" "%s",
+            "Pre-execution script (includes ENVIRONMENT):\n %s",
             environ.read_text(encoding="utf-8"),
         )
 
@@ -202,61 +203,34 @@ class Executor:  # pylint:disable=too-many-instance-attributes
         return environments + self.pre_test_execution
 
     def _triggered(self, test_name):
-        """Send a test case triggered event.
+        """Call on_test_case_triggered for all ETR plugins.
 
         :param test_name: Name of test that is triggered.
         :type test_name: str
-        :return: Test case triggered event created and sent.
-        :rtype: :obj:`eiffellib.events.eiffel_test_case_triggered_event.EiffelTestCaseTriggeredEvent`  # pylint:disable=line-too-long
         """
-        return self.etos.events.send_test_case_triggered(
-            {"id": test_name},
-            self.etos.config.get("artifact"),
-            links={"CONTEXT": self.context},
-        )
+        for plugin in self.plugins:
+            plugin.on_test_case_triggered(test_name)
 
     def _started(self, test_name):
-        """Send a testcase started event.
+        """Call on_test_case_started for all ETR plugins.
 
         :param test_name: Name of test that has started.
         :type test_name: str
-        :return: Test case started event created and sent.
-        :rtype: :obj:`eiffellib.events.eiffel_test_case_started_event.EiffelTestCaseStartedEvent`
         """
-        triggered = self.tests[test_name].get("triggered")
-        if triggered is None:
-            return None
-        return self.etos.events.send_test_case_started(triggered, links={"CONTEXT": self.context})
+        for plugin in self.plugins:
+            plugin.on_test_case_started(test_name)
 
     def _finished(self, test_name, result):
-        """Send a testcase finished event.
+        """Call on_test_case_finished for all ETR plugins.
 
         :param test_name: Name of test that is finished.
         :type test_name: str
         :param result: Result of test case.
         :type result: str
-        :return: Test case finished event created and sent.
-        :rtype: :obj:`eiffellib.events.eiffel_test_case_finished_event.EiffelTestCaseFinishedEvent`
         """
-        triggered = self.tests[test_name].get("triggered")
-        if triggered is None:
-            return None
-
-        if result == "ERROR":
-            outcome = {"verdict": "FAILED", "conclusion": "INCONCLUSIVE"}
-        elif result == "FAILED":
-            outcome = {"verdict": "FAILED", "conclusion": "FAILED"}
-        elif result == "SKIPPED":
-            outcome = {
-                "verdict": "PASSED",
-                "conclusion": "SUCCESSFUL",
-                "description": "SKIPPED",
-            }
-        else:
-            outcome = {"verdict": "PASSED", "conclusion": "SUCCESSFUL"}
-        return self.etos.events.send_test_case_finished(
-            triggered, outcome, links={"CONTEXT": self.context}
-        )
+        for plugin in self.plugins:
+            plugin.on_test_case_finished(test_name, result)
+        self.current_test = None
 
     def parse(self, line):
         """Parse test output in order to send test case events.
@@ -267,21 +241,25 @@ class Executor:  # pylint:disable=too-many-instance-attributes
         if not isinstance(line, str):
             return
         test_name = self.test_regex["test_name"].findall(line)
-        if test_name:
+        if test_name:  # A new test case has been detected.
             self.current_test = test_name[0]
             self.tests.setdefault(self.current_test, {})
+        elif self.current_test is None:  # No test case has been detected.
+            return
+        current_test = self.current_test
+
         if self.test_regex["triggered"].match(line):
-            self.tests[self.current_test]["triggered"] = self._triggered(self.current_test)
+            self._triggered(current_test)
         if self.test_regex["started"].match(line):
-            self.tests[self.current_test]["started"] = self._started(self.current_test)
+            self._started(current_test)
         if self.test_regex["passed"].match(line):
-            self.tests[self.current_test]["finished"] = self._finished(self.current_test, "PASSED")
+            self._finished(current_test, "PASSED")
         if self.test_regex["failed"].match(line):
-            self.tests[self.current_test]["finished"] = self._finished(self.current_test, "FAILED")
+            self._finished(current_test, "FAILED")
         if self.test_regex["error"].match(line):
-            self.tests[self.current_test]["finished"] = self._finished(self.current_test, "ERROR")
+            self._finished(current_test, "ERROR")
         if self.test_regex["skipped"].match(line):
-            self.tests[self.current_test]["finished"] = self._finished(self.current_test, "SKIPPED")
+            self._finished(current_test, "SKIPPED")
 
     def execute(self, workspace):
         """Execute a test case.
@@ -311,6 +289,7 @@ class Executor:  # pylint:disable=too-many-instance-attributes
             )
 
             self.logger.info("Wait for test to finish.")
+            # We must consume the iterator here, even if we do not parse the lines.
             for _, line in iterator:
                 if self.test_regex:
                     self.parse(line)
